@@ -50,23 +50,29 @@ EBImoran.mc <- function (n, x, listw, nsim, zero.policy = NULL,
     v[v < 0] <- b/x
     z <- (p - b)/sqrt(v)
     if (return_boot) {
-            EBI_boot <- function(var, i, ...) {
-                var <- var[i]
-                return(EBImoran(z=var, ...))
+        EBI_boot <- function(var, i, ...) {
+            var <- var[i]
+            return(EBImoran(z=var, ...))
+        }
+        cores <- get.coresOption()
+        if (is.null(cores)) {
+        parallel <- "no"
+        } else {
+            parallel <- ifelse (get.mcOption(), "multicore", "snow")
+        }
+        ncpus <- ifelse(is.null(cores), 1L, cores)
+        cl <- NULL
+        if (parallel == "snow") {
+            cl <- get.ClusterOption()
+            if (is.null(cl)) {
+                parallel <- "no"
+                warning("no cluster in ClusterOption, parallel set to no")
             }
-            cl <- get("cl", envir = .spdepOptions)
-            if (!is.null(cl) && length(cl) > 1L) {
-                nnsim <- boot_wrapper_in(cl, nsim)
-                lres <- clusterCall(cl, boot, z, statistic=EBI_boot, R=nnsim,
-                    sim="permutation", listw=listw, nn=m, S0=S0,
-                    zero.policy=zero.policy)
-                res <- boot_wrapper_out(lres, match.call())
-            } else {
-                res <- boot(z, statistic=EBI_boot, R=nsim,
-                    sim="permutation", listw=listw, nn=m, S0=S0, 
-                    zero.policy=zero.policy)
-            }
-            return(res)
+        }
+        res <- boot(z, statistic=EBI_boot, R=nsim,
+            sim="permutation", listw=listw, nn=m, S0=S0,
+            zero.policy=zero.policy, parallel=parallel, ncpus=ncpus, cl=cl)
+        return(res)
     }
     res <- numeric(length = nsim + 1)
     for (i in 1:nsim) res[i] <- EBImoran(sample(z), listw, m, 
